@@ -23,6 +23,7 @@ import collections
 
 
 from tensorflow.python.feature_column import feature_column as fc
+from tensorflow.python.feature_column import utils as fc_utils
 from tensorflow.python.framework import dtypes
 from tensorflow.python.framework import ops
 from tensorflow.python.framework import tensor_shape
@@ -63,11 +64,11 @@ def sequence_input_layer(
   watches_embedding = embedding_column(watches, dimension=10)
   columns = [rating, watches]
 
-  features = tf.parse_example(..., features=make_parse_example_spec(columns))
+  features = tf.io.parse_example(..., features=make_parse_example_spec(columns))
   input_layer, sequence_length = sequence_input_layer(features, columns)
 
-  rnn_cell = tf.nn.rnn_cell.BasicRNNCell(hidden_size)
-  outputs, state = tf.nn.dynamic_rnn(
+  rnn_cell = tf.compat.v1.nn.rnn_cell.BasicRNNCell(hidden_size)
+  outputs, state = tf.compat.v1.nn.dynamic_rnn(
       rnn_cell, inputs=input_layer, sequence_length=sequence_length)
   ```
 
@@ -198,11 +199,11 @@ def sequence_categorical_column_with_identity(
   watches_embedding = embedding_column(watches, dimension=10)
   columns = [watches_embedding]
 
-  features = tf.parse_example(..., features=make_parse_example_spec(columns))
+  features = tf.io.parse_example(..., features=make_parse_example_spec(columns))
   input_layer, sequence_length = sequence_input_layer(features, columns)
 
-  rnn_cell = tf.nn.rnn_cell.BasicRNNCell(hidden_size)
-  outputs, state = tf.nn.dynamic_rnn(
+  rnn_cell = tf.compat.v1.nn.rnn_cell.BasicRNNCell(hidden_size)
+  outputs, state = tf.compat.v1.nn.dynamic_rnn(
       rnn_cell, inputs=input_layer, sequence_length=sequence_length)
   ```
 
@@ -242,11 +243,11 @@ def sequence_categorical_column_with_hash_bucket(
   tokens_embedding = embedding_column(tokens, dimension=10)
   columns = [tokens_embedding]
 
-  features = tf.parse_example(..., features=make_parse_example_spec(columns))
+  features = tf.io.parse_example(..., features=make_parse_example_spec(columns))
   input_layer, sequence_length = sequence_input_layer(features, columns)
 
-  rnn_cell = tf.nn.rnn_cell.BasicRNNCell(hidden_size)
-  outputs, state = tf.nn.dynamic_rnn(
+  rnn_cell = tf.compat.v1.nn.rnn_cell.BasicRNNCell(hidden_size)
+  outputs, state = tf.compat.v1.nn.dynamic_rnn(
       rnn_cell, inputs=input_layer, sequence_length=sequence_length)
   ```
 
@@ -285,11 +286,11 @@ def sequence_categorical_column_with_vocabulary_file(
   states_embedding = embedding_column(states, dimension=10)
   columns = [states_embedding]
 
-  features = tf.parse_example(..., features=make_parse_example_spec(columns))
+  features = tf.io.parse_example(..., features=make_parse_example_spec(columns))
   input_layer, sequence_length = sequence_input_layer(features, columns)
 
-  rnn_cell = tf.nn.rnn_cell.BasicRNNCell(hidden_size)
-  outputs, state = tf.nn.dynamic_rnn(
+  rnn_cell = tf.compat.v1.nn.rnn_cell.BasicRNNCell(hidden_size)
+  outputs, state = tf.compat.v1.nn.dynamic_rnn(
       rnn_cell, inputs=input_layer, sequence_length=sequence_length)
   ```
 
@@ -346,11 +347,11 @@ def sequence_categorical_column_with_vocabulary_list(
   colors_embedding = embedding_column(colors, dimension=3)
   columns = [colors_embedding]
 
-  features = tf.parse_example(..., features=make_parse_example_spec(columns))
+  features = tf.io.parse_example(..., features=make_parse_example_spec(columns))
   input_layer, sequence_length = sequence_input_layer(features, columns)
 
-  rnn_cell = tf.nn.rnn_cell.BasicRNNCell(hidden_size)
-  outputs, state = tf.nn.dynamic_rnn(
+  rnn_cell = tf.compat.v1.nn.rnn_cell.BasicRNNCell(hidden_size)
+  outputs, state = tf.compat.v1.nn.dynamic_rnn(
       rnn_cell, inputs=input_layer, sequence_length=sequence_length)
   ```
 
@@ -402,11 +403,11 @@ def sequence_numeric_column(
   temperature = sequence_numeric_column('temperature')
   columns = [temperature]
 
-  features = tf.parse_example(..., features=make_parse_example_spec(columns))
+  features = tf.io.parse_example(..., features=make_parse_example_spec(columns))
   input_layer, sequence_length = sequence_input_layer(features, columns)
 
-  rnn_cell = tf.nn.rnn_cell.BasicRNNCell(hidden_size)
-  outputs, state = tf.nn.dynamic_rnn(
+  rnn_cell = tf.compat.v1.nn.rnn_cell.BasicRNNCell(hidden_size)
+  outputs, state = tf.compat.v1.nn.dynamic_rnn(
       rnn_cell, inputs=input_layer, sequence_length=sequence_length)
   ```
 
@@ -506,7 +507,7 @@ class _SequenceNumericColumn(
     # sequence length is not affected.
     num_elements = (self._variable_shape.num_elements()
                     if sp_tensor.shape.ndims == 2 else 1)
-    seq_length = fc._sequence_length_from_sparse_tensor(
+    seq_length = fc_utils.sequence_length_from_sparse_tensor(
         sp_tensor, num_elements=num_elements)
 
     return fc._SequenceDenseColumn.TensorSequenceLengthPair(
